#if !defined usrdiagnostic | !defined nesttime
      subroutine nest_rec_bc
#else
      subroutine nest_rec_bc (tsn1,tsn2)
#endif
c
c=======================================================================
c                                                                    ===
c This routine receives the boundary conditions from a larger domain.===
c                                                                    ===
c ------                                                             ===
c Input:                                                             ===
c ------                                                             ===
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /FULLWD/                                                           ===
c                                                                    ===
c    ITT    timestep counter.                     (integer)          ===
c    LABS   disk unit number (13-15) for slabs.   (integer vector)   ===
c                                                                    ===
c /IOUNITS/                                                          ===
c                                                                    ===
c    STDOUT    Unit number for standard output.          (integer)   ===
c                                                                    ===
c /NEST/                                                             ===
c                                                                    ===
c    LRGTID    PVM task identifier for larger grid.      (integer)   ===
c    SPVL      Flag value from larger grid.              (real)      ===
c                                                                    ===
c /OPTIONS/                                                          ===
c                                                                    ===
c  IOPT    various switches from standard input:    (integer vector) ===
c          IOPT(5)  "diagnostic" printing control:                   ===
c                   [0] Terse output.                                ===
c                   [1] Verbose output.                              ===
c          IOPT(8)  Number of tracers exchanged with larger domain.  ===
c                                                                    ===
c /RHOMEAN/                                                          ===
c                                                                    ===
c    SMEAN     Mean salinity subtracted during                       ===
c              computations.                             (real)      ===
c                                                                    ===
c  /VERTICAL/                                                        ===
c                                                                    ===
c     DZV   Thicknesses of UV vertical boxes.       (real array; cm) ===
c                                                                    ===
c -------                                                            ===
c Output:                                                            ===
c -------                                                            ===
#if defined usrdiagnostic & defined nesttime
c                                                                    ===
c    TSN1      Time spent in communications.          (real vector)  ===
c    TSN2      Time spent in auxillary calculations.  (real vector)  ===
#endif
c                                                                    ===
c Common Blocks:                                                     ===
c                                                                    ===
c /BNDATA/                                                           ===
c                                                                    ===
# ifndef surfpress
c    PO        Transport boundary conditions             (real array)===
# else
c    PO        Pressure boundary conditions              (real array)===
# endif
c                                                                    ===
# ifndef surfpress
c /FIELDS/                                                           ===
c                                                                    ===
c    ZTD       Time change of vorticity with BCs.    (real array)    ===
# else
c /SINFO/                                                            ===
c                                                                    ===
c    ZUM   Vertically averaged zonal forcing.        (real array)    ===
c    ZVM   Vertically averaged meridional forcing.   (real array)    ===
# endif
c                                                                    ===
c /VOLDAT/                                                           ===
c                                                                    ===
c    XT        Tracer fields.                            (real array)===
c    XU        Zonal internal mode velocity.             (real array)===
c    XV        Meridional internal mode velocity.        (real array)===
c                                                                    ===
c  Calls:      HOPSRECV,      NEST_ERRCHK                            ===
c  PVM Calls:  PVMFUNPACK                                            ===
c                                                                    ===
c=======================================================================
c
c-----------------------------------------------------------------------
c  Define global data
c-----------------------------------------------------------------------
c
#include <cdefs.h>
#include <param.h>
#include <pconst.h>
#include <fpvm3.h>
#include <bndata.h>
#include <iounits.h>
#include <nest.h>
#include <options.h>
#include <rhomean.h>
#include <workspa.h>
#include <voldat.h>
#include <fullwd.h>
#ifndef surfpress
# include <fields.h>
# include <scalar.h>
#else
# include <sinfo.h>
#endif
#include <vertical.h>
c
c-----------------------------------------------------------------------
c  Define local and equivalence data.
c-----------------------------------------------------------------------
c
      integer bufid,i,j,k,n,nn,status,toff,xip
      logical first
      FLOAT
     *      trc_shft
#if defined usrdiagnostic & defined nesttime
      FLOAT
     &      tsn1(2),tsn2(2),twk(2)
#endif
c
      save first,toff
c
      data first /.true./
c
c=======================================================================
c  Begin executable code.
c=======================================================================
c
c-----------------------------------------------------------------------
c  Set tracer code offset.
c-----------------------------------------------------------------------
c
      if (first) then
         toff  = trofst + iopt(8) + 1
         first = .false.
      end if
c
c-----------------------------------------------------------------------
#ifndef surfpress
c  Receive boundary conditions for transport streamfunction.
#else
c  Receive boundary conditions for surface pressure.
#endif
c-----------------------------------------------------------------------
c
      if (itt.gt.nest_start) then
         if (mod(itt,itt_fac).eq.0) then
#ifndef nest_ext2lrgr
c
            if (iopt(5).eq.1) write (stdout,900)
c
c  Western boundary.
c
            do 15 i = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,psibdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 10 j = 1, jmt
                  if (xvol(j).ne.spvl) pbc0(j,i,itbp,west) = xvol(j)
  10           continue
  15        continue
c
c  Eastern boundary.
c
            do 25 i = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,psibde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 20 j = 1, jmt
                  if (xvol(j).ne.spvl) pbc0(j,i,itbp,east) = xvol(j)
  20           continue
  25        continue
c
c  Southern boundary.
c
            do 35 j = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,psibds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 30 i = 1, imt
                  if (xvol(i).ne.spvl) pbc0(i,j,itbp,south) = xvol(i)
  30           continue
  35        continue
c
c  Northern boundary.
c
            do 45 j = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,psibdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 40 i = 1, imt
                  if (xvol(i).ne.spvl) pbc0(i,j,itbp,north) = xvol(i)
  40           continue
  45        continue
c
#else
c
            write (stdout,900)
c
c  Full field.
c
# if defined usrdiagnostic & defined nesttime
            call dtime (twk)
            tsn2(1) = tsn2(1) + twk(1)
            tsn2(2) = tsn2(2) + twk(2)
# endif
            call hopsrecv ('NEST_REC_BC',lrgtid,psibdw,bufid)
            call pvmfunpack (nstflt,xpal,imt*jmt,1,status)
            call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
            call dtime (twk)
            tsn1(1) = tsn1(1) + twk(1)
            tsn1(2) = tsn1(2) + twk(2)
# endif
c
            do 10 j = 1, jmt
            do 10 i = 1, imt
               xip=i+(j-1)*imt
               pb(i,j)=p(i,j)
               if (xpal(xip).ne.spvl) p(i,j) = xpal(xip)
  10        continue
#endif
         endif
      endif
c
c-----------------------------------------------------------------------
c  Receive boundary conditions for 3D fields.
c-----------------------------------------------------------------------
c
      if (itt.gt.nest_start) then
         if (mod(itt,itt_fac).eq.0) then
c
            if (iopt(5).eq.1) write (stdout,910)
c
c  -- Internal mode zonal velocity.
c
c     Western boundary
c
            do 55 i = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,ucbdyw,bufid)
               call pvmfunpack (nstflt,xvol,jmt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 50 k = 1, km
               do 50 j = 1, jmt
                  xip = j + (k-1)*jmt
                  if (xvol(xip).ne.spvl)
     &               ubc0(j,k,i,itbp,west) = xvol(xip)/dzv(i,j,k)
  50           continue
  55        continue
c
c     Eastern boundary
c
            do 65 i = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,ucbdye,bufid)
               call pvmfunpack (nstflt,xvol,jmt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 60 k = 1, km
               do 60 j = 1, jmt
                  xip = j + (k-1)*jmt
                  if (xvol(xip).ne.spvl)
     &               ubc0(j,k,i,itbp,east) = xvol(xip)/dzv((imt-i),j,k)
  60           continue
  65        continue
c
c     Southern boundary
c
            do 75 j = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,ucbdys,bufid)
               call pvmfunpack (nstflt,xvol,imt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 70 k = 1, km
               do 70 i = 1, imt
                  xip = i + (k-1)*imt
                  if (xvol(xip).ne.spvl)
     &               ubc0(i,k,j,itbp,south) = xvol(xip)/dzv(i,j,k)
  70           continue
  75        continue
c
c     Northern boundary
c
            do 85 j = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,ucbdyn,bufid)
               call pvmfunpack (nstflt,xvol,imt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 80 k = 1, km
               do 80 i = 1, imt
                  xip = i + (k-1)*imt
                  if (xvol(xip).ne.spvl)
     &               ubc0(i,k,j,itbp,north) = xvol(xip)/dzv(i,(jmt-j),k)
  80           continue
  85        continue
c
c  -- Internal mode meridional velocity.
c
c     Western boundary
c
            do 95 i = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vcbdyw,bufid)
               call pvmfunpack (nstflt,xvol,jmt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 90 k = 1, km
               do 90 j = 1, jmt
                  xip = j + (k-1)*jmt
                  if (xvol(xip).ne.spvl)
     &               vbc0(j,k,i,itbp,west) = xvol(xip)/dzv(i,j,k)
  90           continue
  95        continue
c
c     Eastern boundary
c
            do 105 i = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vcbdye,bufid)
               call pvmfunpack (nstflt,xvol,jmt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 100 k = 1, km
               do 100 j = 1, jmt
                  xip = j + (k-1)*jmt
                  if (xvol(xip).ne.spvl)
     &               vbc0(j,k,i,itbp,east) = xvol(xip)/dzv((imt-i),j,k)
 100           continue
 105        continue
c
c     Southern boundary
c
            do 115 j = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vcbdys,bufid)
               call pvmfunpack (nstflt,xvol,imt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 110 k = 1, km
               do 110 i = 1, imt
                  xip = i + (k-1)*imt
                  if (xvol(xip).ne.spvl)
     &               vbc0(i,k,j,itbp,south) = xvol(xip)/dzv(i,j,k)
 110           continue
 115        continue
c
c     Northern boundary
c
            do 125 j = 1, 3
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vcbdyn,bufid)
               call pvmfunpack (nstflt,xvol,imt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 120 k = 1, km
               do 120 i = 1, imt
                  xip = i + (k-1)*imt
                  if (xvol(xip).ne.spvl)
     &               vbc0(i,k,j,itbp,north) = xvol(xip)/dzv(i,(jmt-j),k)
 120           continue
 125        continue
c
c  -- Tracers.
c
            do 170 n = 1, iopt(8)
            do 170 nn = 1, 3
c
               if (n.ne.2) then
                  trc_shft = c0
                 else
                  trc_shft = smean
               end if
c
c     Western boundary
c
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,toff+(n-1)*4,bufid)
               call pvmfunpack (nstflt,xvol,jmt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 130 k = 1, km
               do 130 j = 1, jmt
                  xip = j + (k-1)*jmt
                  if (xvol(xip).ne.spvl)
     &               tbc0(j,k,n,nn,itbp,west) = xvol(xip)-trc_shft
  130           continue
c
c     Eastern boundary
c
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,toff+1+(n-1)*4,bufid)
               call pvmfunpack (nstflt,xvol,jmt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 140 k = 1, km
               do 140 j = 1, jmt
                  xip = j + (k-1)*jmt
                  if (xvol(xip).ne.spvl)
     &               tbc0(j,k,n,nn,itbp,east) = xvol(xip)-trc_shft
 140           continue
c
c     Southern boundary
c
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,toff+2+(n-1)*4,bufid)
               call pvmfunpack (nstflt,xvol,imt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 150 k = 1, km
               do 150 i = 1, imt
                  xip = i + (k-1)*imt
                  if (xvol(xip).ne.spvl)
     &               tbc0(i,k,n,nn,itbp,south) = xvol(xip)-trc_shft
 150           continue
c
c     Northern boundary
c
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
# endif
               call hopsrecv ('NEST_REC_BC',lrgtid,toff+3+(n-1)*4,bufid)
               call pvmfunpack (nstflt,xvol,imt*km,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
# if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
# endif
c
               do 160 k = 1, km
               do 160 i = 1, imt
                  xip = i + (k-1)*imt
                  if (xvol(xip).ne.spvl)
     &               tbc0(i,k,n,nn,itbp,north) = xvol(xip)-trc_shft
 160           continue
c
 170        continue
c
         end if
      end if
c
#ifndef surfpress
c-----------------------------------------------------------------------
c  Receive ZTD boundary conditions from larger domain
c-----------------------------------------------------------------------
c
      if(itt.gt.nest_start)then
         if(mod(itt,itt_fac).eq.0)then
# ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,920)
c
c  Western boundary.
c
            do 185 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vrtbdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 180 j = 1, jmt
                  if (xvol(j).ne.spvl) qbc0(j,nn,itbp,west) = xvol(j)
 180           continue
 185        continue
c
c  Eastern boundary.
c
            do 195 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vrtbde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 190 j = 1, jmt
                  if (xvol(j).ne.spvl) qbc0(j,nn,itbp,east) = xvol(j)
 190           continue
 195        continue
c
c  Southern boundary.
c
            do 205 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vrtbds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 200 i = 1, imt
                  if (xvol(i).ne.spvl) qbc0(i,nn,itbp,south) = xvol(i)
 200           continue
 205        continue
c
c  Northern boundary.
c
            do 215 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,vrtbdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 210 i = 1, imt
                  if (xvol(i).ne.spvl) qbc0(i,nn,itbp,north) = xvol(i)
 210           continue
 215        continue
c
# endif
          endif
       endif
#else
c-----------------------------------------------------------------------
# ifndef freesurf
c  Receive barotropic velocity BCs from larger domain.
# else
c  Receive transport BCs from larger domain.
# endif
c-----------------------------------------------------------------------
c
      if(itt.gt.nest_start)then
         if(mod(itt,itt_fac).eq.0)then
# ifndef nestnultest
c
            if (iopt(5).eq.1) write (stdout,920)
c
c  -------------
c  --- Zonal ---
c  -------------
c
c  Western boundary.
c
            do 185 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zumbdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 180 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) ubaroo(j,nn,itbp,west) = xvol(j)
# else
                  if (xvol(j).ne.spvl) utrano(j,nn,itbp,west) = xvol(j)
# endif
 180           continue
 185        continue
c
c  Eastern boundary.
c
            do 195 nn = 1, 3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zumbde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 190 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) ubaroo(j,nn,itbp,east) = xvol(j)
# else
                  if (xvol(j).ne.spvl) utrano(j,nn,itbp,east) = xvol(j)
# endif
 190           continue
 195        continue
c
c  Southern boundary.
c
            do 205 nn = 1,3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zumbds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 200 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) ubaroo(i,nn,itbp,south) = xvol(i)
# else
                  if (xvol(i).ne.spvl) utrano(i,nn,itbp,south) = xvol(i)
# endif
 200           continue
 205        continue
c
c  Northern boundary.
c
            do 215 nn = 1,3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zumbdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 210 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) ubaroo(i,nn,itbp,north) = xvol(i)
# else
                  if (xvol(i).ne.spvl) utrano(i,nn,itbp,north) = xvol(i)
# endif
 210           continue
 215        continue
c
c  ------------------
c  --- Meridional ---
c  ------------------
c
c  Western boundary.
c
            do 225 nn = 1,3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zvmbdw,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 220 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) vbaroo(j,nn,itbp,west) = xvol(j)
# else
                  if (xvol(j).ne.spvl) vtrano(j,nn,itbp,west) = xvol(j)
# endif
 220           continue
 225        continue
c
c  Eastern boundary.
c
            do 235 nn = 1,3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zvmbde,bufid)
               call pvmfunpack (nstflt,xvol,jmt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 230 j = 1, jmt
# ifndef freesurf
                  if (xvol(j).ne.spvl) vbaroo(j,nn,itbp,east) = xvol(j)
# else
                  if (xvol(j).ne.spvl) vtrano(j,nn,itbp,east) = xvol(j)
# endif
 230           continue
 235        continue
c
c  Southern boundary.
c
            do 245 nn = 1,3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zvmbds,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 240 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) vbaroo(i,nn,itbp,south) = xvol(i)
# else
                  if (xvol(i).ne.spvl) vtrano(i,nn,itbp,south) = xvol(i)
# endif
 240           continue
 245        continue
c
c  Northern boundary.
c
            do 255 nn = 1,3
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn2(1) = tsn2(1) + twk(1)
               tsn2(2) = tsn2(2) + twk(2)
#  endif
               call hopsrecv ('NEST_REC_BC',lrgtid,zvmbdn,bufid)
               call pvmfunpack (nstflt,xvol,imt,1,status)
               call nest_errchk ('NEST_REC_BC','UnPack',status,1,1,1)
#  if defined usrdiagnostic & defined nesttime
               call dtime (twk)
               tsn1(1) = tsn1(1) + twk(1)
               tsn1(2) = tsn1(2) + twk(2)
#  endif
c
               do 250 i = 1, imt
# ifndef freesurf
                  if (xvol(i).ne.spvl) vbaroo(i,nn,itbp,north) = xvol(i)
# else
                  if (xvol(i).ne.spvl) vtrano(i,nn,itbp,north) = xvol(i)
# endif
 250           continue
 255        continue
c
# endif
          endif
       endif
#endif
c-----------------------------------------------------------------------
c  On first call, only need to spread data back in time.
c-----------------------------------------------------------------------
c
      if (itt.eq.0) then
c
c  East and West boundaries.
c
         do 260 nn = 1, 3
         do 260 j = 1, jmt
#if !defined surfpress
            qbc0(j,nn,itb ,west) = qbc0(j,nn,itbp,west)
            qbc0(j,nn,itbm,west) = qbc0(j,nn,itbp,west)
            qbc0(j,nn,itb ,east) = qbc0(j,nn,itbp,east)
            qbc0(j,nn,itbm,east) = qbc0(j,nn,itbp,east)
#elif !defined freesurf
            ubaroo(j,nn,itb ,west) = ubaroo(j,nn,itbp,west)
            ubaroo(j,nn,itbm,west) = ubaroo(j,nn,itbp,west)
            vbaroo(j,nn,itb ,west) = vbaroo(j,nn,itbp,west)
            vbaroo(j,nn,itbm,west) = vbaroo(j,nn,itbp,west)
            ubaroo(j,nn,itb ,east) = ubaroo(j,nn,itbp,east)
            ubaroo(j,nn,itbm,east) = ubaroo(j,nn,itbp,east)
            vbaroo(j,nn,itb ,east) = vbaroo(j,nn,itbp,east)
            vbaroo(j,nn,itbm,east) = vbaroo(j,nn,itbp,east)
#else
            utrano(j,nn,itb ,west) = utrano(j,nn,itbp,west)
            utrano(j,nn,itbm,west) = utrano(j,nn,itbp,west)
            vtrano(j,nn,itb ,west) = vtrano(j,nn,itbp,west)
            vtrano(j,nn,itbm,west) = vtrano(j,nn,itbp,west)
            utrano(j,nn,itb ,east) = utrano(j,nn,itbp,east)
            utrano(j,nn,itbm,east) = utrano(j,nn,itbp,east)
            vtrano(j,nn,itb ,east) = vtrano(j,nn,itbp,east)
            vtrano(j,nn,itbm,east) = vtrano(j,nn,itbp,east)
#endif
            pbc0(j,nn,itb ,west) = pbc0(j,nn,itbp,west)
            pbc0(j,nn,itbm,west) = pbc0(j,nn,itbp,west)
            pbc0(j,nn,itb ,east) = pbc0(j,nn,itbp,east)
            pbc0(j,nn,itbm,east) = pbc0(j,nn,itbp,east)
c
            do 260 k = 1, km
c
               ubc0(j,k,nn,itb ,west) = ubc0(j,k,nn,itbp,west)
               ubc0(j,k,nn,itbm,west) = ubc0(j,k,nn,itbp,west)
               vbc0(j,k,nn,itb ,west) = vbc0(j,k,nn,itbp,west)
               vbc0(j,k,nn,itbm,west) = vbc0(j,k,nn,itbp,west)
               ubc0(j,k,nn,itb ,east) = ubc0(j,k,nn,itbp,east)
               ubc0(j,k,nn,itbm,east) = ubc0(j,k,nn,itbp,east)
               vbc0(j,k,nn,itb ,east) = vbc0(j,k,nn,itbp,east)
               vbc0(j,k,nn,itbm,east) = vbc0(j,k,nn,itbp,east)
c
               do 260 n = 1, nt
c
                  tbc0(j,k,n,nn,itb ,west) = tbc0(j,k,n,nn,itbp,west)
                  tbc0(j,k,n,nn,itbm,west) = tbc0(j,k,n,nn,itbp,west)
                  tbc0(j,k,n,nn,itb ,east) = tbc0(j,k,n,nn,itbp,east)
                  tbc0(j,k,n,nn,itbm,east) = tbc0(j,k,n,nn,itbp,east)
c
 260     continue
c
c  North and South boundaries.
c
         do 270 nn = 1, 3
         do 270 i = 1, imt
#if !defined surfpress
            qbc0(i,nn,itb ,south) = qbc0(i,nn,itbp,south)
            qbc0(i,nn,itbm,south) = qbc0(i,nn,itbp,south)
            qbc0(i,nn,itb ,north) = qbc0(i,nn,itbp,north)
            qbc0(i,nn,itbm,north) = qbc0(i,nn,itbp,north)
#elif !defined freesurf
            ubaroo(i,nn,itb ,south) = ubaroo(i,nn,itbp,south)
            ubaroo(i,nn,itbm,south) = ubaroo(i,nn,itbp,south)
            vbaroo(i,nn,itb ,south) = vbaroo(i,nn,itbp,south)
            vbaroo(i,nn,itbm,south) = vbaroo(i,nn,itbp,south)
            ubaroo(i,nn,itb ,north) = ubaroo(i,nn,itbp,north)
            ubaroo(i,nn,itbm,north) = ubaroo(i,nn,itbp,north)
            vbaroo(i,nn,itb ,north) = vbaroo(i,nn,itbp,north)
            vbaroo(i,nn,itbm,north) = vbaroo(i,nn,itbp,north)
#else
            utrano(i,nn,itb ,south) = utrano(i,nn,itbp,south)
            utrano(i,nn,itbm,south) = utrano(i,nn,itbp,south)
            vtrano(i,nn,itb ,south) = vtrano(i,nn,itbp,south)
            vtrano(i,nn,itbm,south) = vtrano(i,nn,itbp,south)
            utrano(i,nn,itb ,north) = utrano(i,nn,itbp,north)
            utrano(i,nn,itbm,north) = utrano(i,nn,itbp,north)
            vtrano(i,nn,itb ,north) = vtrano(i,nn,itbp,north)
            vtrano(i,nn,itbm,north) = vtrano(i,nn,itbp,north)
#endif
            pbc0(i,nn,itb ,south) = pbc0(i,nn,itbp,south)
            pbc0(i,nn,itbm,south) = pbc0(i,nn,itbp,south)
            pbc0(i,nn,itb ,north) = pbc0(i,nn,itbp,north)
            pbc0(i,nn,itbm,north) = pbc0(i,nn,itbp,north)
c
            do 270 k = 1, km
c
               ubc0(i,k,nn,itb ,south) = ubc0(i,k,nn,itbp,south)
               ubc0(i,k,nn,itbm,south) = ubc0(i,k,nn,itbp,south)
               vbc0(i,k,nn,itb ,south) = vbc0(i,k,nn,itbp,south)
               vbc0(i,k,nn,itbm,south) = vbc0(i,k,nn,itbp,south)
               ubc0(i,k,nn,itb ,north) = ubc0(i,k,nn,itbp,north)
               ubc0(i,k,nn,itbm,north) = ubc0(i,k,nn,itbp,north)
               vbc0(i,k,nn,itb ,north) = vbc0(i,k,nn,itbp,north)
               vbc0(i,k,nn,itbm,north) = vbc0(i,k,nn,itbp,north)
c
               do 270 n = 1, nt
c
                  tbc0(i,k,n,nn,itb ,south) = tbc0(i,k,n,nn,itbp,south)
                  tbc0(i,k,n,nn,itbm,south) = tbc0(i,k,n,nn,itbp,south)
                  tbc0(i,k,n,nn,itb ,north) = tbc0(i,k,n,nn,itbp,north)
                  tbc0(i,k,n,nn,itbm,north) = tbc0(i,k,n,nn,itbp,north)
c
 270     continue
         return
      endif
c
c-----------------------------------------------------------------------
c  Copy boundary data to old boundary arrays.
c-----------------------------------------------------------------------
c
c  East and West boundaries.
c
      do 280 j = 1, jmt
#ifndef surfpress
         po(j,2,west) = qbc0(j,1,itbp,west)/c2dtsf
         po(j,2,east) = qbc0(j,1,itbp,east)/c2dtsf
#endif
         po(j,1,west) = pbc0(j,1,itbp,west)
         po(j,1,east) = pbc0(j,1,itbp,east)
c
         do 280 k = 1, km
c
            uo(j,k,west) = ubc0(j,k,1,itbp,west)
            vo(j,k,west) = vbc0(j,k,1,itbp,west)
            uo(j,k,east) = ubc0(j,k,1,itbp,east)
            vo(j,k,east) = vbc0(j,k,1,itbp,east)
c
            do 280 n = 1, nt
c
               to(j,k,west,n) = tbc0(j,k,n,1,itbp,west)
               to(j,k,east,n) = tbc0(j,k,n,1,itbp,east)
c
 280  continue
c
c  North and South boundaries.
c
      do 290 nn = 1, 3
      do 290 i = 1, imt
#ifndef surfpress
         po(i,2,south) = qbc0(i,1,itbp,south)/c2dtsf
         po(i,2,north) = qbc0(i,1,itbp,north)/c2dtsf
#endif
         po(i,1,south) = pbc0(i,1,itbp,south)
         po(i,1,north) = pbc0(i,1,itbp,north)
c
         do 290 k = 1, km
c
            uo(i,k,south) = ubc0(i,k,1,itbp,south)
            vo(i,k,south) = vbc0(i,k,1,itbp,south)
            uo(i,k,north) = ubc0(i,k,1,itbp,north)
            vo(i,k,north) = vbc0(i,k,1,itbp,north)
c
            do 290 n = 1, nt
c
               to(i,k,south,n) = tbc0(i,k,n,1,itbp,south)
               to(i,k,north,n) = tbc0(i,k,n,1,itbp,north)
c
 290  continue
c
c-----------------------------------------------------------------------
c  Re-apply boundary conditions.  Usually provided or provided-Orlanski.
c-----------------------------------------------------------------------
c
c  Loop over 3D slabs.  Mimic calling sequence in step.F.
c
      call setvert(1)
      call oget(labs(ndiskb),nslab,     +1,tb)
      call oget(labs(ndisk ),nslab,     +1,t )
      call oget(labs(ndiskb),nslab,nslab+1,tbp)
      call oget(labs(ndisk ),nslab,nslab+1,tp )
c
      do 320 j = 2, jmtm2
c
c  Set western and eastern lateral boundary conditions on UA,VA,TA,P,ZTD
c  for row=J-1.
c
        if (j.gt.2) then
          call opop(j-1)
          call boundary(j-1,1)
          call osav(j-1)
        endif
c
c  Set southern lateral boundary conditions on UA,VA,TA,P,ZTD.
c
        if(j.eq.3) then
           call opop(1)
           call setvert(1)
           call boundary(1,2)
           call setvert(j-1)
           call osav(1)
        endif
c
c  Move all slab data down one row.
c
        do 310 k=1,km
        do 310 i=1,imt
           ubm(i,k)=ub (i,k)
           vbm(i,k)=vb (i,k)
           um (i,k)=u  (i,k)
           vm (i,k)=v  (i,k)
           ub (i,k)=ubp(i,k)
           vb (i,k)=vbp(i,k)
           u  (i,k)=up (i,k)
           v  (i,k)=vp (i,k)
           do 300 n=1,nt
              tbm(i,k,n)=tb (i,k,n)
              tm (i,k,n)=t  (i,k,n)
              tb (i,k,n)=tbp(i,k,n)
              t  (i,k,n)=tp (i,k,n)
 300       continue
 310    continue
c
c  Complete read in of J+1 slab.
c
        call oget(labs(ndiskb),nslab,j*nslab+1,tbp)
        call oget(labs(ndisk ),nslab,j*nslab+1,tp )
c
c  Get depths and vertical thicknesses at the tracer points (row=J,J+1)
c  and velocity points (row=J,J-1).
c
        call setvert(j)
 320  continue
c
c  Set western and eastern lateral boundary conditions on UA,VA,TA,P,ZTD
c  for row=JMTM2.
c
      call opop(jmtm2)
      call boundary(jmtm2,1)
      call osav(jmtm2)
c
c  Set northern lateral boundary conditions on UA,VA,TA,P,ZTD.
c
      call opop(jmtm1)
      call setvert(jmtm1)
      call boundary(jmtm1,4)
      call osav(jmtm1)
c
# if defined usrdiagnostic & defined nesttime
      call dtime (twk)
      tsn2(1) = tsn2(1) + twk(1)
      tsn2(2) = tsn2(2) + twk(2)
# endif
#ifdef sunflush
c
c  Flush output buffers.
c
      call flush(stdout)
#endif
c
      return
c
#ifndef surfpress
 900  format ('NEST_REC_BC:  receiving boundary transport')
#else
 900  format ('NEST_REC_BC:  receiving boundary pressure')
#endif
 910  format ('NEST_REC_BC:  receiving bc for 3D fields')
#ifndef surfpress
 920  format ('NEST_REC_BC:  receiving bc for rate of change of ',
     &        'barotropic vorticity')
#else
 920  format('NEST_REC_BC:  receiving bc for vertically integrated RHS')
#endif
c
      end
